@@ -2,6 +2,7 @@
 
 from __future__ import annotations
 
+from pathlib import Path
 from typing import Sequence
 
 from kraken.core import Project, Supplier
@@ -132,10 +133,10 @@ def cargo_clippy(
     return task
 
 
-def cargo_fmt(*, project: Project | None = None) -> None:
+def cargo_fmt(*, all_packages: bool = False, project: Project | None = None) -> None:
     project = project or Project.current()
-    project.do("cargoFmt", CargoFmtTask, group="fmt")
-    project.do("cargoFmtCheck", CargoFmtTask, group="lint", check=True)
+    project.do("cargoFmt", CargoFmtTask, all_packages=all_packages, group="fmt")
+    project.do("cargoFmtCheck", CargoFmtTask, all_packages=all_packages, group="lint", check=True)
 
 
 def cargo_bump_version(
@@ -146,6 +147,7 @@ def cargo_bump_version(
     group: str | None = CARGO_BUILD_SUPPORT_GROUP_NAME,
     registry: str | None = None,
     project: Project | None = None,
+    cargo_toml_file: Path = Path("Cargo.toml"),
 ) -> CargoBumpVersionTask:
     """Get or create a task that bumps the version in `Cargo.toml`.
 
@@ -157,20 +159,27 @@ def cargo_bump_version(
 
     project = project or Project.current()
 
-    return project.do(
+    task = project.do(
         name,
         CargoBumpVersionTask,
         group=group,
         version=version,
         revert=revert,
         registry=registry,
+        cargo_toml_file=cargo_toml_file,
     )
 
+    if project.parent is not None:
+        task.add_relationship(f":{CARGO_BUILD_SUPPORT_GROUP_NAME}", inverse=True)
+
+    return task
+
 
 def cargo_build(
     mode: Literal["debug", "release"],
     incremental: bool | None = None,
     env: dict[str, str] | None = None,
+    workspace: bool = False,
     *,
     group: str | None = "build",
     name: str | None = None,
@@ -183,12 +192,19 @@ def cargo_build(
         specified, the option is not specified and the default behaviour is used.
     :param env: Override variables for the build environment variables. Values in this dictionary override
         variables in :attr:`CargoProject.build_env`.
-    :param name: The name of the task. If not specified, defaults to `:cargoBuild{mode.capitalied()}`.
+    :param name: The name of the task. If not specified, defaults to `:cargoBuild{mode.capitalised()}`.
     :param version: Bump the Cargo.toml version temporarily while building to the given version."""
 
     assert mode in ("debug", "release"), repr(mode)
     project = project or Project.current()
     cargo = CargoProject.get_or_create(project)
+
+    additional_args = []
+    if workspace:
+        additional_args.append("--workspace")
+    if mode == "release":
+        additional_args.append("--release")
+
     task = project.do(
         f"cargoBuild{mode.capitalize()}" if name is None else name,
         CargoBuildTask,
@@ -196,7 +212,7 @@ def cargo_build(
         group=group,
         incremental=incremental,
         target=mode,
-        additional_args=["--release"] if mode == "release" else [],
+        additional_args=additional_args,
         env=Supplier.of_callable(lambda: {**cargo.build_env, **(env or {})}),
     )
     task.add_relationship(f":{CARGO_BUILD_SUPPORT_GROUP_NAME}?")
