@@ -2,7 +2,11 @@
 
 from __future__ import annotations
 
+import json
+import logging
+import subprocess
 from dataclasses import dataclass, fields
+from enum import Enum
 from pathlib import Path
 from typing import Any, List
 
@@ -10,6 +14,8 @@ import tomli
 import tomli_w
 from pydantic import ClassError
 
+logger = logging.getLogger(__name__)
+
 
 @dataclass
 class Bin:
@@ -20,6 +26,80 @@ class Bin:
         return {"name": self.name, "path": self.path}
 
 
+# TODO: Differentiate between lib kinds?
+
+
+class ArtifactKind(Enum):
+    BIN = 1
+    LIB = 2
+
+
+@dataclass
+class Artifact:
+    name: str
+    path: str
+    kind: ArtifactKind
+
+    def to_json(self) -> dict[str, str]:
+        return {"name": self.name, "path": self.path, "kind": str(self.kind)}
+
+
+@dataclass
+class WorkspaceMember:
+    id: str
+    name: str
+    version: str
+    edition: str
+    manifest_path: Path
+
+
+@dataclass
+class CargoMetadata:
+    _path: Path
+    _data: dict[str, Any]
+
+    workspaceMembers: list[WorkspaceMember]
+    artifacts: list[Artifact]
+
+    @classmethod
+    def read(cls, project_dir: Path) -> CargoMetadata:
+        cmd = [
+            "cargo",
+            "metadata",
+            "--no-deps",
+            "--format-version=1",
+            "--manifest-path",
+            str(project_dir / "Cargo.toml"),
+        ]
+        result = subprocess.run(cmd, stdout=subprocess.PIPE)
+        if result.returncode == 0:
+            logger.warning(f"Could not execute `{' '.join(cmd)}`, please see logs.")
+            logger.warning("If this is your first run of kraken, you may need to execute :cargoSyncConfig first.")
+            return cls.of(project_dir, {"packages": []})
+        else:
+            return cls.of(project_dir, json.loads(result.stdout.decode("utf-8")))
+
+    @classmethod
+    def of(cls, path: Path, data: dict[str, Any]) -> CargoMetadata:
+        workspace_members = []
+        artifacts = []
+        for package in data["packages"]:
+            id = package["id"]
+            if id in data["workspace_members"]:
+                workspace_members.append(
+                    WorkspaceMember(
+                        id, package["name"], package["version"], package["edition"], Path(package["manifest_path"])
+                    )
+                )
+                for target in package["targets"]:
+                    if "bin" in target["kind"]:
+                        artifacts.append(Artifact(target["name"], target["src_path"], ArtifactKind.BIN))
+                    elif "lib" in target["kind"]:
+                        artifacts.append(Artifact(target["name"], target["src_path"], ArtifactKind.LIB))
+
+        return cls(path, data, workspace_members, artifacts)
+
+
 @dataclass
 class Package:
     name: str
@@ -76,7 +156,10 @@ class Workspace:
         )
 
     def to_json(self) -> dict[str, Any]:
-        values = {"package": self.package.to_json() if self.package else None}
+        values = {
+            "package": self.package.to_json() if self.package else None,
+            "members": self.members if self.members else None,
+        }
         if self.unhandled is not None:
             values.update({k: v for k, v in self.unhandled.items() if v is not None})
         return {k: v for k, v in values.items() if v is not None}
