@@ -2,8 +2,8 @@ import logging
 from pathlib import Path
 from typing import Dict, List
 
+from kraken.common import not_none
 from kraken.core import Project, Property
-from kraken.core.util.helpers import not_none
 
 from ..config import CargoRegistry
 from .cargo_build_task import CargoBuildTask
