@@ -18,7 +18,7 @@ class Flake8Task(EnvironmentAwareDispatchTask):
     def get_execute_command(self) -> list[str]:
         command = ["flake8", str(self.settings.source_directory)] + self.settings.get_tests_directory_as_args()
         if self.config_file.is_filled():
-            command += ["--config", str(self.config_file.get())]
+            command += ["--config", str(self.config_file.get().absolute())]
         command += self.additional_args.get()
         return command
 
